#include <math.h>
#include <stdio.h>

typedef struct {
    double slope;
    double yint;
} eq;

/* return the slope and y-intercept of a line given one point and angle */
eq get_equation(double p1x, double p1y, double angle) {
    eq result;

    /* find a triangle on the given line */
    double a = 1.0;
    double b = tan(angle * (M_PI / 180.0));

    /* find the second point on the line */
    double p2x = p1x + a;
    double p2y = p1y + b;

    /* find the slope and y intercept */
    result.slope = (p2y - p1y) / (p2x - p1x);
    result.yint = p1y - result.slope * p1x;
    return result;
}

/* returns whether a point is "above" a given line */
int above_line(double px, double py, eq line) {
    /* find the line's y value at the point's X */
    double line_y = line.slope * px + line.yint;
 
    /* return whether the point's Y is above this value */
    return py >= line_y;
}

/* returns whether a line intercepts a square */
int line_intercept_square(double targetX, double targetY, eq line) {
    /* find the corner points in the sqaure */
    double left = targetX - 0.5;
    double right = targetX + 0.5;
    double top = targetY + 0.5;
    double bottom = targetY - 0.5;
 
    /* for each corner, find whether it's above the line */
    int a = above_line(left, top, line);
    int b = above_line(right, top, line);
    int c = above_line(right, bottom, line);
    int d = above_line(left, bottom, line);
 
    /* if a=b=c=d, then NO */
    if (a && b && c && d)
        return 0;

    if (!a && !b && !c && !d)
        return 0;

    return 1;
}

int test() {
    /* get all input */
    double p1x, p1y, targetX, targetY, angle;
    scanf("%lf %lf", &p1x, &p1y);
    scanf("%lf %lf", &targetX, &targetY);
    scanf("%lf", &angle);

    /* get the equation for the line */
    eq line = get_equation(p1x, p1y, angle);
    
    /* test if the line intercepts the target */
    if (line_intercept_square(targetX, targetY, line)) {
        /* now test if the line is the right "direction" */
        /* if the target is above Link, angle must be in 0-180! */
        if (targetY > p1y) {
            if (angle < 180.0) {
                return 1;
            } else {
                return 0;
            }
        } else {
            /* slope must be over 180 */
            if (angle > 180.0) {
                return 1;
            } else {
                return 0;
            }
        }
    } else {
        return 0;
    }
}

int main() {
    if (test()) {
        printf("Link hits the target!\n");
    } else {
        printf("Link does not hit the target!\n");
    }
}


