#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/* find the location of link */
void find_link(char** light, char** dark, int width, int height, int* row, int*
        col, int* in_light) {
    int i, j;

    /* search the light world */
    for (i = 0; i < height; i++) {
        for (j = 0; j < width; j++) {
            if (light[i][j] == 'L') {
                *row = i;
                *col = j;
                *in_light = 1;
                return;
            }
        }
    }

    /* search the dark world */
    for (i = 0; i < height; i++) {
        for (j = 0; j < width; j++) {
            if (dark[i][j] == 'L') {
                *row = i;
                *col = j;
                *in_light = 0;
                return;
            }
        }
    }
}

/* run through DFS on the maps */
int dfs(char** world, char** other, int width, int height, int row, int col, int light) {
    /* if we're out of bounds, no */
    if (row < 0 || col < 0 || row >= height || col >= width) {
        return 0;
    }

    /* if it's an obstacles or we've been here, no */
    char p = world[row][col];
    if (p == 'T' || p == 'W' || p == 'M' || p == 'X') {
        return 0;
    }

    /* if we are at the destination, then yes! */
    if (world[row][col] == 'D') {
        return 1;
    }

    /* check if we're on a portal, and mark that we've been here */
    int portal = (world[row][col] == 'P');
    world[row][col] = 'X';

    /* if we are on a portal, try to go to dark world */
    if (portal && dfs(other, world, width, height, row, col, !light)) return 1;

    /* if we are in dark world, try using mirror */
    if (!light && dfs(other, world, width, height, row, col, !light)) return 1;

    /* check all of the directions */
    if (dfs(world, other, width, height, row, col - 1, light)) return 1;
    if (dfs(world, other, width, height, row, col + 1, light)) return 1;
    if (dfs(world, other, width, height, row - 1, col, light)) return 1;
    if (dfs(world, other, width, height, row + 1, col, light)) return 1;

    /* if none of that worked, I guess we can't make it */
    return 0;
}

int main() {
    int i, height, width, row, col, in_light;

    /* read the height of the maps */
    scanf("%d\n", &height);

    /* read the first line of input */
    char* first = NULL;
    size_t n = 0;
    getline(&first, &n, stdin);

    /* the width is the length - 1 (for \n) */
    width = strlen(first) - 1;

    /* allocate and read the light world */
    char** light = malloc(height * sizeof(char*));
    light[0] = first;
    light[0][width] = '\0';
    for (i = 1; i < height; i++) {
        getline(&light[i], &n, stdin);
        light[i][width] = '\0';
    }

    /* skip over the blank line separating them */
    getline(&first, &n, stdin);

    /* allocate and read the dark world */
    char** dark = malloc(height * sizeof(char*));
    for (i = 0; i < height; i++) {
        getline(&dark[i], &n, stdin);
        dark[i][width] = '\0';
    }

    /* find the location of Link initially */
    find_link(light, dark, width, height, &row, &col, &in_light);

    /* run through the DFS and print result */
    if (dfs(in_light ? light : dark, in_light ? dark : light, width, height,
                row, col, in_light)) {
        printf("Link can make it to his destination!\n");
    } else {
        printf("Link can NOT make it to his destination!\n"); 
    }

    /* free allocated memory */
    for (i = 0; i < height; i++) {
        free(light[i]);
        free(dark[i]);
    }
    free(light);
    free(dark);

    return 0;
}

