#include <stdio.h>
#include <string.h>
#define MAX_DOORS 100
#define TRANS_TIME 5.0

double total_distance;
int ndoors;
double doors[MAX_DOORS];

/* a struct for holding the time and number of transformations */
typedef struct {
    double t;
    int n;
} res;

/* this function returns the time takens to go along a path
 * in a current form WITHOUT any possible transformations */
double time(double distance, int wolf) {
    if (wolf) {
        return distance / 10.0;
    } else {
        return distance / 4.0;
    }
}

/* this function returns the time taken to open a door in the
 * current form WITHOUT and possible transformations */
double door_time(int wolf) {
    if (wolf) {
        return 8.0;
    } else {
        return 1.0;
    }
}

/* this function returns the next door, or NULL if there is no next door */
double* next_door(double position) {
    int i;

    for (i = 0; i < ndoors; i++) {
        if (doors[i] > position) {
            return doors + i;
        }
    }

    return NULL;
}


/* this function returns the minimum time, and transformations needed,
 * to traverse a path of a given distance, with give amount of doors */
res minimize(double position, int wolf) {
    /* if we're at the end, it's easy */
    if (position >= total_distance) {
        res zip;
        zip.t = 0.0;
        zip.n = 0;
        return zip;
    }

    /* find end position for this trek */
    double end;
    int last = 0;
    double* end_ptr = next_door(position);
    if (end_ptr) {
        end = *end_ptr;
    } else {
        last = 1;
        end = total_distance;
    }

    if (wolf) {
        /* if we're a wolf, run to the end */
        double base = time(end - position, 1);

        /* option a is to open as wolf */
        res a = minimize(end, 1);
        if (!last)
            a.t += door_time(1);

        /* option b is to transform to a human to open the door */
        res b = minimize(end, 0);
        if (!last) {
            b.t += door_time(0);
            b.t += TRANS_TIME;
            b.n++;
        }

        /* find smallest, and add in base */
        res final;
        if (a.t < b.t) {
            final.t = a.t;
            final.n = a.n;
        } else {
            final.t = b.t;
            final.n = b.n;
        }
        final.t += base;
        return final;


    } else {
        /* if we're a human, we should decide whether to turn into a wolf */

        /* option a is to stay a human, and walk to the next door */
        res a = minimize(end, 0); // time after this point as human
        a.t += time(end - position, 0); // time to walk the distance
        if (!last)
            a.t += door_time(0); // time to open the door

        /* option b is to transform to a wolf, and sprint to the next door, and open as wolf */
        res b = minimize(end, 1); // time after this as wolf
        b.t += time(end - position, 1); // time on this leg as wolf
        if (!last)
            b.t += door_time(1);        // open the door
        b.t += TRANS_TIME;     // TRANS time
        b.n++;

        /* option c is to transform to a wolf, sprint to the next door, transform back to human! */
        res c = minimize(end, 0);  // after as human
        c.t += time(end - position, 1); // time running as wolf
        if (!last)
            c.t += door_time(0);        // time to open door as man
        c.t += 2*TRANS_TIME;        // transforms
        c.n += 2;

        /* find smallest */
        res final;
        if ((a.t < b.t) && (a.t < c.t)) {
            final.t = a.t;
            final.n = a.n;
        } else if (b.t < c.t) {
            final.t = b.t;
            final.n = b.n;
        } else {
            final.t = c.t;
            final.n = c.n;
        }
        return final;
    }
}

int main() {
    int i;

    /* read all input in */
    scanf("%lf", &total_distance);
    scanf("%d", &ndoors);
    for (i = 0; i < ndoors; i++) {
        scanf("%lf", doors + i);
    }

    res answer = minimize(0.0, 0);
    printf("Link could travel this distance in %lf seconds, by transforming %d time%s.\n",
            answer.t, answer.n, (answer.n == 1) ? "" : "s");

    return 0;
}

